---
name: "✨ Feature request"
about: Suggest a new idea or enhancement
title: "[Feature] "
labels: enhancement
assignees: svange
---

## ✨ Description

## 🚀 Why is this useful?

## 🔗 Related issues or context
